#pragma once

namespace code {
	namespace eh {

		// Activate stack info in stack traces.
		void activatePosixInfo();

	}
}
